@@ -103,22 +103,16 @@ typedef struct EbSvtAv1DecConfiguration
 
     EbColorFormat           max_color_format;
 
-    /* Assembly instruction set used by encoder.
-    *
-    * 0 = non-AVX2, C only.
-    * 1 = up to AVX512, auto-select highest assembly instruction set supported.
-    *
-    * Default is 1. */
-    uint32_t                 asm_type;
     // Application Specific parameters
 
     /* Number of threads used by decoder.
-    *
-    * 0 = System default.
-    * 1 = Single thread decoding.
-    *
-    * Default is 0. */
+     * Default is 1. */
     uint32_t                 threads;
+
+    /* Number of frames that can be processed
+       in parallel. Default is 1 */
+    uint32_t                 num_p_frames;
+
     // Application Specific parameters
 
     /* ID assigned to each channel when multiple instances are running within the
