@@ -26,6 +26,8 @@ extern "C" {
 
 #define MAX_ENC_PRESET                              8
 
+#define DEFAULT                                    -1
+
 #define EB_BUFFERFLAG_EOS           0x00000001  // signals the last packet of the stream
 #define EB_BUFFERFLAG_SHOW_EXT      0x00000002  // signals that the packet contains a show existing frame at the end
 #define EB_BUFFERFLAG_HAS_TD        0x00000004  // signals that the packet contains a TD
@@ -230,6 +232,106 @@ typedef struct EbSvtAv1EncConfiguration
     * Default is 1. */
     EbBool                   enable_global_motion;
 
+    /* Restoration filtering
+    *
+    * Default is -1. */
+    int                   enable_restoration_filtering;
+
+    /* edge based skip angle intra
+    *
+    * Default is -1. */
+    int                      edge_skp_angle_intra;
+
+    /* inter intra compound
+    *
+    * Default is -1. */
+    int                      inter_intra_compound;
+
+    /* fractional search 64
+    *
+    * Default is -1. */
+    int                      fract_search_64;
+
+    /* combine class 12
+    *
+    * Default is -1. */
+    int                      combine_class_12;
+
+    /* motion field motion vector
+    *
+    *  Default is -1. */
+    int                   enable_mfmv;
+    /* redundant block
+    *
+    * Default is -1. */
+    int                   enable_redundant_blk;
+    /* trellis quant coeff optimization
+    *
+    * Default is -1. */
+    int                   enable_trellis;
+    /* spatial sse in full loop
+    *
+    * Default is -1. */
+    int                   spatial_sse_fl;
+    /* subpel
+    *
+    * Default is -1. */
+    int                   enable_subpel;
+    /* over boundry block
+    *
+    * Default is -1. */
+    int                   over_bndry_blk;
+    /* new nearest comb injection
+    *
+    * Default is -1. */
+    int                   new_nearest_comb_inject;
+    /* nx4 4xn parent motion vector injection
+    *
+    * Default is -1. */
+    int                   nx4_4xn_parent_mv_inject;
+    /* prune unipred at me
+    *
+    * Default is -1. */
+    int                   prune_unipred_me;
+    /* prune ref frame for rec partitions
+    *
+    * Default is -1. */
+    int                   prune_ref_rec_part;
+    /* nsq table
+    *
+    * Default is -1. */
+    int                   nsq_table;
+    /* frame end cdf update
+    *
+    * Default is -1. */
+    int                   frame_end_cdf_update;
+
+    /* Predictive Me
+    *
+    * Default is -1. */
+    int                   pred_me;
+
+    /* Bipred 3x3 Injection
+    *
+    * Default is -1. */
+    int                   bipred_3x3_inject;
+
+    /* Compound Mode
+    *
+    * Default is -1. */
+    int                   compound_level;
+
+    /* Chroma mode
+    *
+    * Level                Settings
+    * CHROMA_MODE_0  0     Full chroma search @ MD
+    * CHROMA_MODE_1  1     Fast chroma search @ MD
+    * CHROMA_MODE_2  2     Chroma blind @ MD + CFL @ EP
+    * CHROMA_MODE_3  3     Chroma blind @ MD + no CFL @ EP
+    *
+    * Default is -1 (AUTO) */
+    int                   set_chroma_mode;
+
     /* OBMC
     *
     * Default is 1. */
@@ -238,7 +340,7 @@ typedef struct EbSvtAv1EncConfiguration
     /* RDOQ
     *
     * Default is -1. */
-    int8_t                   enable_rdoq;
+    int                      enable_rdoq;
 
     /* Filter intra prediction
     *
@@ -321,10 +423,14 @@ typedef struct EbSvtAv1EncConfiguration
     uint32_t                 look_ahead_distance;
 
     /* Target bitrate in bits/second, only apllicable when rate control mode is
-     * set to 1.
+     * set to 2 or 3.
      *
      * Default is 7000000. */
     uint32_t                 target_bit_rate;
+
+    /* VBV Buffer size */
+    uint32_t                 vbv_bufsize;
+
     /* Maxium QP value allowed for rate control use, only applicable when rate
      * control mode is set to 1. It has to be greater or equal to minQpAllowed.
      *
@@ -373,13 +479,10 @@ typedef struct EbSvtAv1EncConfiguration
      * Default is 0. */
     uint32_t                 level;
 
-    /* Assembly instruction set used by encoder.
-    *
-    * 0 = non-AVX2, C only.
-    * 1 = up to AVX512, auto-select highest assembly instruction set supported.
-    *
-    * Default is 1. */
-    uint32_t                 asm_type;
+    /* CPU FLAGS to limit assembly instruction set used by encoder.
+    * Default is CPU_FLAGS_ALL. */
+    CPU_FLAGS            use_cpu_flags;
+
     // Application Specific parameters
 
     /* ID assigned to each channel when multiple instances are running within the
@@ -415,6 +518,15 @@ typedef struct EbSvtAv1EncConfiguration
      * OS thread scheduler. */
     uint32_t                logical_processors;
 
+    /* Unpin the execution . If logical_processors is set to 1, this option does not
+    * set the execution to be pinned to core #0 when set to 1. this allows the execution
+    * of multiple encodes on the CPU wihtout having to pin them to a specific mask
+    * 1: unpinned from core 0
+    * 0: pinned to core 0
+    *
+    * Default is 1. */
+    uint32_t                unpin_lp1;
+
     /* Target socket to run on. For dual socket systems, this can specify which
      * socket the encoder runs on.
      *
@@ -487,6 +599,9 @@ typedef struct EbSvtAv1EncConfiguration
     uint64_t                 md_stage_2_class_prune_th;
     uint64_t                 md_stage_2_cand_prune_th;
 
+    // signal for automax_partition; on by default
+    uint8_t                     enable_auto_max_partition;
+
 } EbSvtAv1EncConfiguration;
 
     /* STEP 1: Call the library to construct a Component Handle.
